..
    Copyright (C) 2021 Graz University of Technology.

    invenio-campusonline is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version v0.4.2 (release 2024-03-12)

- fix: parameter ordering
- fix: copy paste error


Version v0.4.1 (release 2024-03-08)

- fix: wrong name


Version v0.4.0 (release 2024-02-27)

- setup: remove unused dependency
- setup: add support for python3.12
- fix: tests, indentation is a problem
- fix: missing function
- setup: move ruff configuration
- refactor: finalize it of last two commits
- refactor: follow up of the previous commit
- refactor: to use service structure
- types: remove state from ThesisFilter


Version v0.3.0 (release 2023-11-03)

- cli: add command duplicate-check
- setup: increase min python version
- cli: add command set_status
- ruff: remove todos
- cli: add full sync command
- ruff rules update


Version v0.2.0 (release 2023-05-25)

- utils: implement get_embargo_range
- setup: migrate to ruff


Version v0.1.2 (release 2023-05-01)

- cli: move to secho way from logger


Version v0.1.1 (release 2023-01-11)

- setup: remove python3.8 add python3.11 support
- setup: remove translation config


Version v0.1.0 (release 2023-01-11)




Version 0.1.0 (released TBD)

- Initial public release.
